@@ -872,7 +872,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
             let sanitizedFilename = sanitizeName(getFilenameWithFormat(item, format));
             const content = await stringifyRequestViaWorker(item, { format });
             const filePath = path.join(currentPath, sanitizedFilename);
-            safeWriteFileSync(filePath, content, { mode: 600 });
+            safeWriteFileSync(filePath, content);
           }
           if (item.type === 'folder') {
             let sanitizedFolderName = sanitizeName(item?.filename || item?.name);
@@ -883,7 +883,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
               const folderFilePath = path.join(folderPath, `folder.${format}`);
               item.root.meta.seq = item.seq;
               const folderContent = await stringifyFolder(item.root, { format });
-              safeWriteFileSync(folderFilePath, folderContent, { mode: 600 });
+              safeWriteFileSync(folderFilePath, folderContent);
             }
 
             if (item.items && item.items.length) {
@@ -894,7 +894,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
           if (item.type === 'js') {
             let sanitizedFilename = sanitizeName(item?.filename || `${item.name}.js`);
             const filePath = path.join(currentPath, sanitizedFilename);
-            safeWriteFileSync(filePath, item.fileContent, { mode: 600 });
+            safeWriteFileSync(filePath, item.fileContent);
           }
         }));
       };
@@ -909,7 +909,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
           const content = await stringifyEnvironment(env, { format });
           let sanitizedEnvFilename = sanitizeName(`${env.name}.${format}`);
           const filePath = path.join(envDirPath, sanitizedEnvFilename);
-          safeWriteFileSync(filePath, content, { mode: 600 });
+          safeWriteFileSync(filePath, content);
         }));
       };
 
@@ -982,7 +982,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
             const newFilename = format === 'yml' ? `${baseName}.yml` : `${baseName}.bru`;
             const filePath = path.join(currentPath, newFilename);
 
-            safeWriteFileSync(filePath, content, { mode: 600 });
+            safeWriteFileSync(filePath, content);
           }
           if (item.type === 'folder') {
             const folderPath = path.join(currentPath, item.filename);
@@ -994,7 +994,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
               folderContent.name = item.name;
               if (folderContent) {
                 const folderFilePath = path.join(folderPath, `folder.${format}`);
-                safeWriteFileSync(folderFilePath, folderContent, { mode: 600 });
+                safeWriteFileSync(folderFilePath, folderContent);
               }
             }
 
@@ -1012,7 +1012,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
         const folderContent = await stringifyFolder(itemFolder.root, { format });
         if (folderContent) {
           const folderFilePath = path.join(collectionPath, `folder.${format}`);
-          safeWriteFileSync(folderFilePath, folderContent, { mode: 600 });
+          safeWriteFileSync(folderFilePath, folderContent);
         }
       }
 
@@ -1075,7 +1075,7 @@ const registerRendererEventHandlers = (mainWindow, watcher) => {
       moveRequestUid(itemPath, newItemPath);
 
       fs.unlinkSync(itemPath);
-      safeWriteFileSync(newItemPath, itemContent), { mode: 600 };
+      safeWriteFileSync(newItemPath, itemContent);
     } catch (error) {
       return Promise.reject(error);
     }
