@@ -1,5 +1,6 @@
 const _ = require('lodash');
 const Store = require('electron-store');
+const fs = require('fs');
 
 class CollectionSecurityStore {
   constructor() {
@@ -22,11 +23,21 @@ class CollectionSecurityStore {
       });
 
       this.store.set('collections', collections);
+      try {
+        fs.chmodSync(store.path, 0o600);
+      } catch (error) {
+        console.error('Error setting file permissions:', error);
+      }
       return;
     }
 
     collection.securityConfig = securityConfig || {};
     this.store.set('collections', collections);
+    try {
+      fs.chmodSync(store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
   }
 
   getSecurityConfigForCollection(collectionPathname) {
