@@ -1,6 +1,7 @@
 const path = require('node:path');
 const _ = require('lodash');
 const Store = require('electron-store');
+const fs = require('fs');
 const { isDirectory } = require('../utils/filesystem');
 
 class LastOpenedCollections {
@@ -24,11 +25,21 @@ class LastOpenedCollections {
     if (isDirectory(collectionPath) && !collections.includes(collectionPath)) {
       collections.push(collectionPath);
       this.store.set('lastOpenedCollections', collections);
+      try {
+        fs.chmodSync(this.store.path, 0o600);
+      } catch (error) {
+        console.error('Error setting file permissions:', error);
+      }
     }
   }
 
   update(collectionPaths) {
     this.store.set('lastOpenedCollections', collectionPaths);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
   }
 
   remove(collectionPath) {
@@ -37,11 +48,21 @@ class LastOpenedCollections {
     if (collections.includes(collectionPath)) {
       collections = _.filter(collections, (c) => c !== collectionPath);
       this.store.set('lastOpenedCollections', collections);
+      try {
+        fs.chmodSync(this.store.path, 0o600);
+      } catch (error) {
+        console.error('Error setting file permissions:', error);
+      }
     }
   }
 
   removeAll() {
     this.store.set('lastOpenedCollections', []);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
   }
 }
 
