@@ -1,4 +1,5 @@
 const Store = require('electron-store');
+const fs = require('fs');
 
 class LastOpenedWorkspaces {
   constructor() {
@@ -21,6 +22,11 @@ class LastOpenedWorkspaces {
 
     workspaces.unshift(workspacePath);
     this.store.set('workspaces.lastOpenedWorkspaces', workspaces);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
     return workspaces;
   }
 
@@ -28,6 +34,11 @@ class LastOpenedWorkspaces {
     const workspaces = this.getAll();
     const filteredWorkspaces = workspaces.filter((w) => w !== workspacePath);
     this.store.set('workspaces.lastOpenedWorkspaces', filteredWorkspaces);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
     return filteredWorkspaces;
   }
 }
