@@ -1,4 +1,5 @@
 const Store = require('electron-store');
+const fs = require('fs');
 
 const DEFAULT_WINDOW_WIDTH = 1280;
 const DEFAULT_WINDOW_HEIGHT = 768;
@@ -26,6 +27,11 @@ class WindowStateStore {
 
   setBounds(bounds) {
     this.store.set('window-bounds', bounds);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
   }
 
   getMaximized() {
@@ -34,6 +40,11 @@ class WindowStateStore {
 
   setMaximized(isMaximized) {
     this.store.set('maximized', isMaximized);
+    try {
+      fs.chmodSync(this.store.path, 0o600);
+    } catch (error) {
+      console.error('Error setting file permissions:', error);
+    }
   }
 }
 
